### Tools

- This project is inspired by [opta](https://github.com/run-x/opta), _a tool quite ahead of its time, and got discontinued way before its time_. I would like to thank the team behind it for their work and providing me inspiration to condense the idea of deployment of MLOps tools into a single tool.
- The project leans heavily on [terraform aws modules](https://github.com/terraform-aws-modules/) by [Anton Babenko](https://www.linkedin.com/in/antonbabenko/) for the AWS infrastructure.

### Resources

- [Road Rage font](https://www.fontspace.com/road-rage-font-f43310)
- [Dall-E](https://openai.com/dall-e-2) for the wonderful background
- [AWS EKS Best Practices Guide](https://aws.github.io/aws-eks-best-practices/)

### People

I would also like to thank the following individuals:

- [Ghania Riaz](https://www.linkedin.com/in/ghaniariaz) for her patience in bearing me with a laptop on weekdays, holidays and our vacations!
- [Nicholas Junge](https://www.linkedin.com/in/nicholas-junge/) for his valuable feedback and support in the early stages of this project.
- [Hamza Tahir](https://www.linkedin.com/in/hamzatahirofficial): an old friend and an endless source of inspiration on my journey in the MLOps space.
